#line 1 "scanner.c"

#line 3 "scanner.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define aalogparse__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer aalogparse__create_buffer
#endif

#ifdef yy_delete_buffer
#define aalogparse__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer aalogparse__delete_buffer
#endif

#ifdef yy_scan_buffer
#define aalogparse__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer aalogparse__scan_buffer
#endif

#ifdef yy_scan_string
#define aalogparse__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string aalogparse__scan_string
#endif

#ifdef yy_scan_bytes
#define aalogparse__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes aalogparse__scan_bytes
#endif

#ifdef yy_init_buffer
#define aalogparse__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer aalogparse__init_buffer
#endif

#ifdef yy_flush_buffer
#define aalogparse__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer aalogparse__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define aalogparse__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state aalogparse__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define aalogparse__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer aalogparse__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define aalogparse_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state aalogparse_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define aalogparse_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state aalogparse_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define aalogparse_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack aalogparse_ensure_buffer_stack
#endif

#ifdef yylex
#define aalogparse_lex_ALREADY_DEFINED
#else
#define yylex aalogparse_lex
#endif

#ifdef yyrestart
#define aalogparse_restart_ALREADY_DEFINED
#else
#define yyrestart aalogparse_restart
#endif

#ifdef yylex_init
#define aalogparse_lex_init_ALREADY_DEFINED
#else
#define yylex_init aalogparse_lex_init
#endif

#ifdef yylex_init_extra
#define aalogparse_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra aalogparse_lex_init_extra
#endif

#ifdef yylex_destroy
#define aalogparse_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy aalogparse_lex_destroy
#endif

#ifdef yyget_debug
#define aalogparse_get_debug_ALREADY_DEFINED
#else
#define yyget_debug aalogparse_get_debug
#endif

#ifdef yyset_debug
#define aalogparse_set_debug_ALREADY_DEFINED
#else
#define yyset_debug aalogparse_set_debug
#endif

#ifdef yyget_extra
#define aalogparse_get_extra_ALREADY_DEFINED
#else
#define yyget_extra aalogparse_get_extra
#endif

#ifdef yyset_extra
#define aalogparse_set_extra_ALREADY_DEFINED
#else
#define yyset_extra aalogparse_set_extra
#endif

#ifdef yyget_in
#define aalogparse_get_in_ALREADY_DEFINED
#else
#define yyget_in aalogparse_get_in
#endif

#ifdef yyset_in
#define aalogparse_set_in_ALREADY_DEFINED
#else
#define yyset_in aalogparse_set_in
#endif

#ifdef yyget_out
#define aalogparse_get_out_ALREADY_DEFINED
#else
#define yyget_out aalogparse_get_out
#endif

#ifdef yyset_out
#define aalogparse_set_out_ALREADY_DEFINED
#else
#define yyset_out aalogparse_set_out
#endif

#ifdef yyget_leng
#define aalogparse_get_leng_ALREADY_DEFINED
#else
#define yyget_leng aalogparse_get_leng
#endif

#ifdef yyget_text
#define aalogparse_get_text_ALREADY_DEFINED
#else
#define yyget_text aalogparse_get_text
#endif

#ifdef yyget_lineno
#define aalogparse_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno aalogparse_get_lineno
#endif

#ifdef yyset_lineno
#define aalogparse_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno aalogparse_set_lineno
#endif

#ifdef yyget_column
#define aalogparse_get_column_ALREADY_DEFINED
#else
#define yyget_column aalogparse_get_column
#endif

#ifdef yyset_column
#define aalogparse_set_column_ALREADY_DEFINED
#else
#define yyset_column aalogparse_set_column
#endif

#ifdef yywrap
#define aalogparse_wrap_ALREADY_DEFINED
#else
#define yywrap aalogparse_wrap
#endif

#ifdef yyget_lval
#define aalogparse_get_lval_ALREADY_DEFINED
#else
#define yyget_lval aalogparse_get_lval
#endif

#ifdef yyset_lval
#define aalogparse_set_lval_ALREADY_DEFINED
#else
#define yyset_lval aalogparse_set_lval
#endif

#ifdef yyalloc
#define aalogparse_alloc_ALREADY_DEFINED
#else
#define yyalloc aalogparse_alloc
#endif

#ifdef yyrealloc
#define aalogparse_realloc_ALREADY_DEFINED
#else
#define yyrealloc aalogparse_realloc
#endif

#ifdef yyfree
#define aalogparse_free_ALREADY_DEFINED
#else
#define yyfree aalogparse_free
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define aalogparse_wrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 132
#define YY_END_OF_BUFFER 133
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[405] =
    {   0,
      130,  130,  133,  117,  132,    1,  117,  132,    1,  132,
       15,  117,  132,   53,  117,  132,   49,  117,  132,   50,
      117,  132,   48,  117,  132,   51,  117,  132,   46,  117,
      132,   47,  117,  132,   45,  117,  132,   52,  117,  132,
      117,  132,  117,  132,  117,  132,  117,  132,  117,  132,
      117,  132,  117,  132,  117,  132,  117,  132,  117,  132,
      117,  132,  117,  132,  117,  132,  117,  132,  117,  132,
      117,  132,  117,  132,  117,  132,  117,  132,  117,  132,
      117,  132,  117,  132,  117,  132,  117,  132,  117,  132,
      117,  132,  117,  132,  117,  132,  132,   18,  132,   16,

      132,  132,   13,  132,   11,  132,   11,   13,  132,   12,
      132,    9,  132,   10,  132,   14,  132,    8,  132,    6,
        8,  132,    7,    8,  132,    5,    8,  132,    2,    8,
      132,    4,    8,  132,  118,  132,  120,  132,  120,  132,
      123,  132,  121,  123,  132,  121,  132,  123,  132,   22,
      132,   19,   22,  132,   22,  132,   21,   22,  132,   44,
      132,   44,  132,   43,   44,  132,   27,   43,   44,  132,
       26,   44,  132,   43,   44,  132,   43,   44,  132,   25,
      132,   25,  132,   24,   25,  132,  129,  132,  124,  129,
      132,  124,  132,  128,  129,  132,  127,  129,  132,  129,

      132,  129,  132,  130,  132,  131,  132,    1,   46,   18,
       17,   13,    2,    3,  118,  120,  120,  121,   20,   43,
       27,   43,   43,   43,   43,   43,  124,  130,   46,  111,
      111,  111,  111,  111,  111,  111,  111,  111,  111,  111,
      111,   99,   89,   56,   70,   85,   82,  120,   43,   40,
       43,   43,   43,   23,  126,   46,  111,  111,   87,   83,
       90,   68,   61,   58,   81,  100,  104,   65,   55,  120,
       43,   43,   43,   23,  110,   46,  111,  111,  115,   79,
       96,  106,   98,   80,   74,   95,   97,   59,   84,  120,
       43,   43,   43,  125,  111,   76,  105,  102,   93,   66,

      103,   94,  120,   31,   43,   43,   43,  111,   92,  109,
       72,  107,  120,   29,   33,   43,   43,   43,  114,  111,
      111,  111,   54,   86,   71,   78,   88,  120,   28,   32,
       43,   43,   41,   43,  111,   64,  101,   60,   57,   69,
       77,  120,   30,   43,   43,  112,  114,   91,   75,  120,
       43,   43,   43,   43,   43,   42,   43,16497,   62,   67,
      120,   43,   43,   43,   43,   43,   43,  108,   73,  119,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       37,   43,   43,  114,  116,   63,  122,   43,   35,   43,
       43,   39,   43,   43,   43,   34,   43,   38,   43,   36,

       43, 8305, 8305, 8305
    } ;

static const flex_int16_t yy_accept[664] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    2,    3,    4,    6,    9,   11,   14,
       17,   20,   23,   26,   29,   32,   35,   38,   41,   43,
       45,   47,   49,   51,   53,   55,   57,   59,   61,   63,
       65,   67,   69,   71,   73,   75,   77,   79,   81,   83,
       85,   87,   89,   91,   93,   95,   97,   98,  100,  102,
      103,  105,  107,  110,  112,  114,  116,  118,  120,  123,
      126,  129,  132,  135,  137,  139,  141,  143,  146,  148,
      150,  152,  155,  157,  160,  162,  164,  167,  171,  174,

      177,  180,  182,  184,  187,  189,  192,  194,  197,  200,
      202,  204,  206,  208,  209,  209,  209,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  210,
      210,  210,  210,  210,  210,  210,  210,  210,  210,  211,
      212,  213,  214,  215,  216,  217,  218,  219,  219,  220,
      220,  220,  220,  220,  220,  221,  223,  224,  225,  226,
      227,  227,  228,  228,  228,  229,  229,  230,  230,  231,

      232,  233,  234,  235,  236,  237,  238,  239,  240,  241,
      242,  242,  242,  242,  242,  242,  242,  243,  243,  243,
      243,  243,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  245,
      245,  245,  245,  245,  245,  245,  245,  246,  246,  246,
      246,  247,  247,  247,  247,  247,  247,  247,  247,  248,
      249,  249,  249,  249,  249,  249,  249,  249,  249,  250,
      252,  253,  254,  255,  255,  256,  256,  257,  257,  257,
      257,  257,  257,  257,  258,  259,  259,  259,  259,  259,
      259,  260,  260,  260,  260,  261,  261,  261,  262,  262,

      262,  262,  262,  262,  262,  262,  262,  262,  263,  263,
      263,  263,  263,  263,  263,  264,  264,  265,  265,  265,
      266,  266,  267,  268,  268,  268,  268,  268,  268,  268,
      268,  268,  269,  269,  270,  271,  271,  271,  271,  271,
      271,  271,  271,  272,  273,  274,  275,  275,  276,  276,
      277,  277,  278,  278,  278,  278,  278,  279,  279,  279,
      279,  279,  279,  279,  280,  280,  280,  280,  281,  282,
      282,  283,  284,  284,  285,  285,  285,  285,  285,  285,
      285,  286,  287,  288,  288,  288,  289,  289,  289,  289,
      289,  289,  289,  289,  289,  290,  290,  290,  290,  290,

      290,  290,  291,  291,  291,  291,  291,  291,  291,  291,
      292,  293,  294,  295,  295,  295,  296,  296,  296,  296,
      296,  296,  296,  296,  296,  296,  296,  296,  296,  297,
      298,  298,  298,  298,  298,  298,  298,  299,  299,  300,
      300,  301,  301,  301,  301,  301,  301,  301,  302,  302,
      302,  303,  303,  303,  304,  304,  304,  304,  304,  304,
      305,  305,  306,  307,  308,  308,  308,  308,  308,  308,
      309,  309,  309,  309,  309,  309,  309,  310,  310,  310,
      310,  310,  310,  311,  311,  311,  311,  311,  311,  311,
      311,  312,  312,  312,  312,  313,  313,  313,  314,  314,

      314,  314,  315,  315,  316,  316,  317,  318,  319,  319,
      320,  321,  322,  323,  323,  323,  324,  324,  324,  324,
      325,  325,  325,  325,  325,  325,  325,  325,  325,  326,
      326,  327,  327,  327,  328,  328,  329,  329,  329,  330,
      331,  332,  333,  335,  335,  335,  335,  336,  336,  337,
      337,  337,  338,  338,  338,  338,  339,  340,  341,  341,
      341,  341,  342,  342,  343,  343,  344,  345,  346,  347,
      347,  348,  348,  349,  349,  349,  349,  349,  350,  350,
      350,  350,  351,  351,  352,  353,  354,  355,  356,  358,
      359,  359,  359,  360,  360,  360,  361,  361,  361,  361,

      362,  362,  363,  364,  365,  366,  367,  368,  368,  368,
      368,  369,  370,  370,  371,  371,  372,  373,  374,  375,
      376,  377,  377,  377,  377,  377,  377,  378,  379,  380,
      381,  383,  384,  384,  385,  385,  386,  387,  387,  388,
      389,  391,  392,  394,  395,  395,  396,  398,  400,  400,
      402,  402,  402,  403,  403,  403,  403,  404,  404,  404,
      404,  405,  405
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    1,    1,    1,    1,    8,    9,
       10,    1,   11,    1,   12,   13,    1,   14,   14,   15,
       14,   14,   14,   14,   14,   14,   14,   16,    1,    1,
       17,    1,   18,    1,   19,   20,   21,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   31,   32,   33,   34,
       25,   35,   36,   37,   38,   39,   40,   25,   25,   25,
       41,   42,   43,    1,   44,    1,   45,   46,   47,   48,

       49,   50,   51,   52,   53,   25,   54,   55,   56,   57,
       58,   59,   60,   61,   62,   63,   64,   65,   25,   66,
       67,   25,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[68] =
    {   0,
        1,    2,    3,    1,    2,    2,    4,    2,    2,    2,
        1,    5,    6,    5,    5,    1,    2,    1,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        7,    8,    9,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5
    } ;

static const flex_int16_t yy_base[683] =
    {   0,
        0,    0,    0,    0,   65,   66,   72,   88,  100,  108,
      124,  178,   97,  149,  230,  252,  276,  318,  358,  406,
      153,  157, 1553, 1552, 1554, 1557,   81,  141, 1557, 1557,
     1557, 1557, 1512, 1557,  122, 1557, 1557, 1557,  151, 1511,
       63,   98,  127,  130,   29,  152,  156,  202,  163,  136,
      167,  165,  162,  201,   30,  107,  189,  198,  255,  190,
      247,  297,  199,  304,  299,  183, 1557,    0, 1557,    0,
        0, 1557,    0, 1557, 1557, 1557, 1557, 1557, 1557, 1557,
     1557,  105,  305,  365,    0, 1502, 1557,  374,  378,  298,
     1557, 1557,  370, 1557, 1557,  279,    0,  135, 1557,  195,

      226, 1557,  382, 1557, 1557,  397,  408, 1557, 1557, 1486,
     1487,    0, 1557,  412, 1507,  250,  419,  200,  300,  377,
      306,  298,  384,  396,  289,  323,  385,  431,  399,  402,
      401,  417,  397,  407,  421,  302,  408,  426,  430,  427,
      160,  432,  435,  438,  433,  439,  258,  440,  442,  441,
      443,  459,  462,  452,  449,  465,  467,  463,  466,  472,
      475,  476,  477,  478,  479,  481,  487,  482,    0, 1557,
        0,  373, 1557,  529,    0, 1486,  545,  524,  537,  505,
     1523, 1510, 1517, 1506,    0,  530, 1508, 1520, 1511, 1516,
      549,  564, 1490, 1486,    0,  539,  559,  556,  531,  514,

      534,  540,  538,  536,  539,  544, 1495,  563,  535,  545,
      600,  546,  565,  548,  570,  572, 1494,  576,  575,  577,
      578, 1493,  581,  584,  583,  585,  586,  587,  591,  594,
      598,  600,  601,  597,  602,  603,  607,  614, 1492,  610,
      608,  617,  621,  623,  624,  625, 1491,  627,  630,  626,
     1490,  632,  633,  634,  641,  639,  640,  654, 1489, 1472,
      683,  685, 1498, 1505, 1494, 1490, 1492, 1504, 1503,    0,
     1489, 1485,  697, 1466, 1557, 1502,  707,  669,  660,  661,
      673,  675,  679, 1476, 1475,  676,  677,  684,  685,  722,
     1474,  690,  697,  691, 1473,  694,  708, 1472,  711,  700,

      714,  715,  716,  717,  718,  721,  722, 1471,  723,  784,
      726,  735,  724,  725, 1470,  733,  758,  757,  762, 1469,
      764, 1468,  727,  763,  770,  768,  767,  769,  778,  789,
      782, 1467,  771, 1466,  834,  832, 1473, 1478, 1477, 1470,
     1465, 1464, 1465, 1466, 1454,  840, 1434, 1557,  843,  850,
     1480, 1454,  807,  772,  818,  788, 1453,  820,  819,  826,
      857,  837,  828, 1452,  839,  838,  854, 1451, 1450,  832,
     1449, 1448,  855, 1447,  856,  857, 1430,  859,  891,  862,
     1445, 1444, 1443,  867,  868, 1442,  869,  871,  872,  873,
      884,  877,  874,  879, 1441,  883,  881,  886,  882,  889,

     1424, 1423,  935, 1439, 1441, 1454, 1441, 1468, 1436, 1442,
     1432, 1452, 1557,  937,  939, 1429,  906,  915,  890,  917,
      918,  919,  956,  922,  921,  926,  923,  933, 1428, 1427,
      927,  941, 1409,  932,  959,  943, 1425,  946, 1424,  948,
     1423,  947,  951,  952,  953,  954,  956, 1422,  957,  958,
     1421,  969, 1403, 1402, 1003, 1436, 1451, 1435, 1449, 1557,
     1419, 1421, 1421, 1413,  991, 1006,  968,  970,  974, 1410,
      981, 1026, 1011,  982,  986,  992, 1409,  995,  993,  997,
     1386,  987, 1557, 1005, 1006, 1007, 1011, 1013,  885, 1014,
     1407, 1015, 1017, 1016, 1406, 1019, 1383, 1382, 1063, 1065,

     1422, 1557, 1436, 1557, 1435, 1406, 1399, 1418, 1067, 1072,
     1397, 1396, 1395, 1026, 1074, 1394, 1045, 1028, 1051, 1393,
     1049, 1380, 1052, 1056, 1054, 1058, 1059, 1060, 1391, 1021,
     1390, 1063, 1065, 1389, 1376, 1375, 1098, 1420, 1557, 1557,
     1382, 1104,    0, 1106, 1108, 1110, 1384, 1112, 1383, 1061,
     1075, 1382, 1375, 1088, 1089, 1380, 1379, 1378, 1090, 1091,
     1092, 1377, 1370, 1369, 1125, 1557, 1127, 1127, 1111, 1140,
     1145, 1147, 1374, 1110, 1365, 1117, 1124, 1372, 1127, 1128,
     1363, 1362, 1157, 1137, 1381, 1360, 1359, 1345,    0, 1159,
     1364, 1162, 1330, 1354, 1162, 1328, 1138, 1144, 1341, 1337,

     1176, 1322, 1326, 1209, 1183, 1156, 1167, 1178, 1180, 1182,
     1557, 1102, 1139, 1557, 1184, 1101, 1080, 1046, 1031,  846,
      844, 1167, 1190, 1192, 1161, 1195,  792,  746,  662,  557,
        0,  552, 1197, 1557, 1199, 1557,  448, 1202, 1557,  427,
        0,  341,    0,  234, 1206,  246,    0,    0,  160,    0,
     1208, 1210, 1215, 1215, 1217, 1219, 1225,   90, 1229, 1232,
     1557, 1557, 1247, 1256, 1265, 1274, 1283, 1292, 1301, 1310,
     1319, 1328, 1337, 1342, 1349, 1358, 1367, 1372, 1374, 1383,
     1392, 1401
    } ;

static const flex_int16_t yy_def[683] =
    {   0,
      662,    1,  663,  663,  664,  664,  665,  665,  666,  666,
      667,  667,  668,  668,  669,  669,  670,  670,  671,  671,
      672,  672,  673,  673,  662,  662,  662,  662,  662,  662,
      662,  662,  674,  662,  674,  662,  662,  662,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  662,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  662,  675,  662,  676,
      677,  662,  677,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  678,  678,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  679,  679,  662,  679,

      679,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  680,  662,  662,  674,  662,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  662,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  675,  662,
      677,  662,  662,  662,  678,  678,  662,  662,  662,  662,
      662,  662,  662,  662,  679,  679,  679,  679,  679,  679,
      662,  662,  662,  662,  680,  662,  674,  662,  674,  674,

      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      662,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  678,
      662,  662,  662,  662,  662,  662,  662,  662,  679,  679,
      679,  679,  662,  662,  662,  662,  674,  662,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  662,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,

      674,  674,  674,  674,  674,  674,  674,  674,  674,  681,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  682,  662,  662,  662,  662,  662,
      662,  662,  679,  679,  679,  662,  662,  662,  674,  674,
      662,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      662,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  662,  674,  662,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,

      662,  678,  662,  662,  662,  662,  662,  662,  662,  679,
      679,  679,  662,  674,  662,  674,  674,  674,  674,  674,
      674,  674,  662,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  662,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  662,  678,  662,  662,  662,  662,  662,  662,
      662,  679,  679,  679,  674,  662,  674,  674,  674,  674,
      674,  662,  662,  674,  674,  674,  674,  674,  674,  674,
      662,  674,  662,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  674,  674,  662,  678,  662,  662,

      662,  662,  662,  662,  662,  679,  679,  679,  674,  662,
      674,  674,  674,  674,  662,  674,  674,  674,  674,  674,
      674,  662,  674,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  674,  674,  662,  678,  662,  662,  662,  662,
      679,  679,  679,  674,  662,  662,  674,  662,  674,  674,
      674,  674,  662,  674,  674,  674,  674,  674,  674,  674,
      674,  674,  662,  678,  662,  662,  679,  679,  674,  662,
      662,  662,  674,  674,  662,  674,  674,  674,  674,  674,
      662,  678,  662,  679,  679,  679,  679,  679,  679,  674,
      662,  662,  674,  662,  674,  674,  674,  674,  662,  678,

      662,  679,  679,  679,  679,  679,  679,  674,  662,  662,
      662,  674,  674,  662,  662,  679,  679,  679,  679,  679,
      679,  674,  662,  662,  674,  662,  679,  679,  679,  679,
      679,  679,  662,  662,  662,  662,  674,  662,  662,  679,
      679,  679,  679,  679,  662,  679,  679,  679,  662,  679,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,    0,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662
    } ;

static const flex_int16_t yy_nxt[1625] =
    {   0,
       26,   27,   28,   27,   27,   26,   29,   30,   31,   32,
       26,   33,   34,   35,   35,   36,   37,   38,   39,   40,
       40,   41,   40,   42,   40,   40,   40,   43,   40,   40,
       44,   45,   46,   40,   40,   47,   40,   40,   40,   40,
       48,   26,   26,   40,   49,   50,   51,   52,   53,   54,
       40,   55,   56,   57,   58,   59,   60,   61,   62,   40,
       63,   64,   65,   66,   40,   40,   40,   67,   67,  116,
      116,   69,   69,   72,   72,   73,   72,   67,   74,   67,
       75,   76,  114,  114,  114,  114,  125,  143,   77,   72,
       72,   73,   72,   67,   74,   67,   75,   76,   88,   89,

       88,   88,   67,  116,   77,  659,   70,   70,   79,   80,
       67,  120,   81,   82,   82,   83,   79,   80,  172,  172,
       81,   82,   82,   83,   67,   84,   84,   84,   84,   67,
       67,   67,   67,   67,   67,  117,  117,   90,  116,   67,
       67,   67,  114,  114,  114,  114,  121,  116,  186,  186,
       88,   89,   88,   88,  106,  107,  106,  106,  106,  107,
      106,  106,  116,  144,   67,   67,   67,  116,  108,  109,
      116,  122,  108,  109,  124,  651,  116,   86,   67,   84,
       84,   84,   84,   67,   67,   67,   67,   67,   67,   90,
      123,  116,  116,   67,   67,   67,  116,  110,  126,  133,

      116,  110,  116,  116,  127,  116,  128,  116,  111,  118,
      129,  134,  111,  136,  119,  128,  128,  226,   67,   67,
       67,  130,  137,  116,  135,  131,  132,  138,  187,  116,
      116,   86,   67,  188,  151,  168,   92,  145,  116,  116,
      116,  116,  146,   93,   93,  139,   94,  159,   93,   93,
       93,   93,   93,   93,   67,  140,  147,  189,   92,  141,
      199,  190,  142,  196,  196,   93,   93,  650,   94,  648,
       93,   93,   93,   93,   93,   93,   95,   95,   67,   95,
       95,   95,   96,   95,   95,   95,   95,  116,   95,   98,
       98,   95,   99,   95,  100,  116,  152,  180,  116,  148,

      181,  182,  178,  149,  183,  153,  173,  173,  173,  173,
      154,  178,  178,  101,  184,  235,  150,   95,   95,   95,
       67,   95,   95,   95,   96,   95,   95,   95,   95,  116,
       95,   98,   98,   95,   99,   95,  100,  116,  116,  116,
      116,  155,  116,  165,  116,  156,  116,  166,  160,  157,
      200,  202,  161,  208,  203,  101,  162,  158,  220,   95,
       67,  163,  647,  116,  164,  167,  174,  174,  174,  174,
      103,  103,  103,  103,  104,  177,  177,  177,  177,  177,
      177,  177,  177,  179,  179,  209,  172,  172,  179,  179,
      179,  179,  179,  179,  191,  191,  191,  191,  192,  192,

      192,  192,  103,  103,  103,  103,  103,  103,   67,  192,
      192,  192,  192,  114,  114,  114,  114,  116,  103,  103,
      103,  103,  104,  201,  116,  116,  191,  191,  191,  191,
      191,  191,  197,  197,  198,  211,  116,  116,  204,  116,
      205,  116,  116,  210,  211,  211,  212,  116,  116,  646,
      103,  103,  103,  103,  103,  103,  206,  116,  217,  116,
      213,  116,  207,  214,  215,  218,  116,  116,  221,  216,
      116,  225,  116,  116,  222,  116,  219,  223,  116,  116,
      116,  116,  116,  116,  233,  224,  234,  230,  116,  116,
      236,  239,  116,  232,  227,  228,  229,  238,  240,  116,

      231,  237,  116,  116,  243,  116,  116,  116,  241,  244,
      242,  245,  116,  246,  247,  116,  116,  116,  116,  116,
      248,  116,  116,  253,  254,  249,  252,  116,  261,  259,
      174,  174,  174,  174,  263,  250,  251,  261,  261,  255,
      256,  257,  264,  186,  186,  258,  177,  177,  177,  177,
      262,  262,  196,  196,  116,  262,  262,  262,  262,  262,
      262,  273,  273,  273,  273,  192,  192,  192,  192,  278,
      278,  116,  277,  277,  116,  116,  116,  280,  116,  116,
      116,  276,  281,  279,  116,  116,  116,  285,  116,  644,
      286,  643,  288,  273,  273,  273,  273,  273,  273,  116,

      282,  283,  284,  116,  290,  116,  291,  289,  293,  292,
      116,  287,  116,  290,  290,  116,  116,  116,  116,  295,
      296,  116,  294,  116,  116,  116,  116,  116,  301,  299,
      298,  116,  297,  303,  116,  300,  302,  116,  116,  306,
      116,  116,  116,  116,  312,  304,  309,  116,  116,  311,
      116,  308,  305,  307,  116,  314,  310,  116,  317,  316,
      315,  116,  313,  116,  116,  116,  116,  116,  320,  318,
      116,  321,  116,  116,  116,  322,  324,  319,  327,  116,
      116,  116,  351,  351,  642,  323,  329,  336,  328,  325,
      330,  331,  332,  326,  116,  333,  336,  336,  179,  179,

      116,  116,  334,  179,  179,  179,  179,  179,  179,  346,
      346,  346,  346,  116,  352,  116,  116,  116,  349,  116,
      350,  350,  353,  356,  116,  116,  361,  357,  354,  359,
      116,  116,  358,  360,  116,  361,  361,  116,  355,  365,
      116,  346,  346,  346,  346,  346,  346,  116,  116,  363,
      362,  116,  366,  364,  116,  116,  116,  116,  116,  367,
      368,  116,  116,  116,  116,  116,  116,  116,  374,  370,
      391,  384,  386,  116,  369,  116,  373,  371,  375,  372,
      381,  385,  641,  376,  377,  377,  383,  377,  377,  377,
      377,  377,  377,  377,  377,  382,  377,  116,  116,  377,

      377,  377,  116,  116,  116,  388,  389,  116,  116,  116,
      116,  116,  116,  396,  395,  392,  394,  417,  116,  387,
      390,  397,  116,  400,  379,  377,  377,  393,  116,  116,
      399,  640,  380,  398,  401,  401,  403,  401,  401,  401,
      401,  401,  401,  401,  401,  403,  403,  116,  419,  401,
      401,  401,  346,  346,  346,  346,  414,  414,  116,  116,
      116,  423,  418,  350,  350,  420,  116,  421,  116,  416,
      423,  423,  116,  425,  401,  401,  401,  116,  116,  116,
      632,  422,  631,  116,  346,  346,  346,  346,  346,  346,
      116,  426,  424,  427,  116,  116,  116,  116,  429,  116,

      431,  428,  116,  430,  196,  196,  432,  116,  116,  116,
      436,  116,  116,  116,  116,  434,  435,  116,  434,  116,
      446,  116,  116,  116,  116,  116,  116,  438,  437,  116,
      116,  445,  529,  439,  440,  441,  442,  448,  443,  455,
      447,  450,  444,  449,  451,  452,  116,  433,  455,  455,
      465,  465,  466,  466,  467,  116,  207,  116,  116,  116,
      472,  116,  116,  116,  471,  469,  116,  116,  473,  472,
      472,  477,  116,  116,  483,  468,  478,  116,  470,  474,
      476,  116,  479,  116,  475,  480,  116,  116,  116,  482,
      485,  116,  116,  116,  116,  488,  116,  116,  116,  116,

      486,  491,  509,  487,  489,  484,  495,  499,  116,  116,
      116,  492,  490,  496,  116,  500,  499,  499,  493,  510,
      510,  116,  116,  494,  515,  515,  116,  116,  511,  514,
      472,  116,  116,  116,  513,  116,  512,  116,  473,  472,
      472,  520,  516,  521,  518,  116,  116,  116,  517,  523,
      519,  116,  525,  116,  116,  116,  116,  116,  528,  116,
      527,  116,  524,  630,  526,  532,  116,  499,  116,  531,
      560,  530,  629,  534,  533,  500,  499,  499,  537,  537,
      544,  544,  545,  545,  546,  116,  547,  548,  548,  116,
      550,  116,  116,  549,  116,  551,  116,  552,  116,  116,

      116,  116,  556,  116,  554,  116,  628,  116,  559,  555,
      561,  565,  565,  562,  557,  116,  558,  568,  568,  569,
      569,  570,  570,  571,  571,  572,  572,  573,  116,  116,
      116,  116,  116,  627,  576,  580,  574,  577,  583,  583,
      568,  568,  116,  579,  578,  584,  116,  590,  585,  586,
      116,  116,  587,  591,  591,  545,  545,  116,  571,  571,
      592,  592,  588,  593,  116,  595,  602,  116,  116,  589,
      601,  601,  608,  608,  603,  610,  610,  611,  116,  116,
      596,  597,  633,  598,  116,  621,  612,  620,  613,  615,
      615,  622,  622,  623,  623,  624,  624,  626,  626,  116,

      625,  116,  116,  634,  634,  635,  635,  116,  638,  638,
      645,  645,  635,  635,  637,  638,  638,  619,  116,  649,
      649,  652,  652,  653,  653,  654,  654,  655,  656,  656,
      657,  657,  658,  658,  636,  654,  654,  639,  657,  657,
      618,  636,  660,  660,  639,  661,  661,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   68,   68,   68,   68,
       68,   68,   68,   68,   68,   71,   71,   71,   71,   71,
       71,   71,   71,   71,   78,   78,   78,   78,   78,   78,
       78,   78,   78,   85,   85,   85,   85,   85,   85,   85,
       85,   85,   87,   87,   87,   87,   87,   87,   87,   87,

       87,   91,   91,   91,   91,   91,   91,   91,   91,   91,
       97,   97,   97,   97,   97,   97,   97,   97,   97,  102,
      102,  102,  102,  102,  102,  102,  102,  102,  105,  105,
      105,  105,  105,  105,  105,  105,  105,  112,  112,  112,
      112,  112,  112,  112,  112,  112,  115,  617,  115,  169,
      169,  616,  614,  169,  169,  169,  614,  169,  170,  170,
      170,  170,  170,  170,  170,  170,  170,  171,  116,  611,
      116,  171,  171,  171,  171,  171,  175,  175,  185,  609,
      185,  607,  185,  195,  195,  606,  195,  195,  195,  195,
      195,  195,  378,  378,  605,  378,  378,  378,  378,  378,

      378,  402,  402,  604,  402,  402,  402,  402,  402,  402,
      600,  599,  116,  594,  116,  582,  581,  116,  116,  116,
      116,  575,  116,  116,  116,  567,  566,  564,  563,  116,
      116,  116,  553,  116,  116,  116,  116,  116,  543,  542,
      541,  540,  539,  538,  536,  535,  116,  116,  522,  116,
      116,  508,  507,  506,  505,  504,  503,  502,  501,  498,
      497,  116,  116,  116,  116,  116,  481,  116,  116,  116,
      464,  463,  462,  461,  460,  459,  458,  457,  456,  454,
      453,  116,  116,  116,  116,  116,  433,  116,  116,  116,
      116,  116,  116,  116,  116,  415,  413,  412,  411,  410,

      409,  408,  407,  406,  405,  404,  116,  116,  116,  116,
      116,  116,  116,  116,  116,  116,  116,  348,  347,  345,
      344,  343,  342,  341,  340,  339,  338,  337,  335,  116,
      116,  116,  116,  116,  116,  116,  275,  274,  272,  271,
      270,  269,  268,  267,  266,  265,  260,  116,  194,  193,
      176,  116,  116,  662,  113,  113,   25,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,

      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662
    } ;

static const flex_int16_t yy_chk[1625] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    5,    6,   45,
       55,    5,    6,    7,    7,    7,    7,    7,    7,    7,
        7,    7,   27,   27,   27,   27,   45,   55,    7,    8,
        8,    8,    8,    8,    8,    8,    8,    8,   13,   13,

       13,   13,    9,   41,    8,  658,    5,    6,    9,    9,
       10,   41,    9,    9,    9,    9,   10,   10,   82,   82,
       10,   10,   10,   10,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   35,   35,   13,   42,   11,
       11,   11,   28,   28,   28,   28,   42,   56,   98,   98,
       14,   14,   14,   14,   21,   21,   21,   21,   22,   22,
       22,   22,   35,   56,   11,   11,   11,   43,   21,   21,
       44,   43,   22,   22,   44,  649,   50,   11,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   12,   12,   14,
       43,   39,   46,   12,   12,   12,   47,   21,   46,   50,

      141,   22,   53,   49,   47,   52,   48,   51,   21,   39,
       49,   51,   22,   52,   39,   48,   48,  141,   12,   12,
       12,   49,   53,   66,   51,   49,   49,   53,  100,   57,
       60,   12,   15,  100,   60,   66,   15,   57,   58,   63,
      118,   54,   58,   15,   15,   54,   15,   63,   15,   15,
       15,   15,   15,   15,   16,   54,   58,  101,   16,   54,
      118,  101,   54,  116,  116,   16,   16,  646,   16,  644,
       16,   16,   16,   16,   16,   16,   17,   17,   17,   17,
       17,   17,   17,   17,   17,   17,   17,   61,   17,   17,
       17,   17,   17,   17,   17,   59,   61,   96,  147,   59,

       96,   96,   90,   59,   96,   61,   83,   83,   83,   83,
       61,   90,   90,   17,   96,  147,   59,   17,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,  125,
       18,   18,   18,   18,   18,   18,   18,   62,  122,   65,
      119,   62,  136,   65,   64,   62,  121,   65,   64,   62,
      119,  121,   64,  125,  122,   18,   64,   62,  136,   18,
       19,   64,  642,  126,   64,   65,   84,   84,   84,   84,
       19,   19,   19,   19,   19,   88,   88,   88,   88,   89,
       89,   89,   89,   93,   93,  126,  172,  172,   93,   93,
       93,   93,   93,   93,  103,  103,  103,  103,  106,  106,

      106,  106,   19,   19,   19,   19,   19,   19,   20,  107,
      107,  107,  107,  114,  114,  114,  114,  120,   20,   20,
       20,   20,   20,  120,  123,  127,  103,  103,  103,  103,
      103,  103,  117,  117,  117,  128,  124,  133,  123,  129,
      123,  131,  130,  127,  128,  128,  129,  134,  137,  640,
       20,   20,   20,   20,   20,   20,  124,  132,  133,  117,
      130,  135,  124,  131,  132,  134,  138,  140,  137,  132,
      139,  140,  142,  145,  138,  143,  135,  139,  144,  146,
      148,  150,  149,  151,  146,  139,  146,  144,  637,  155,
      148,  150,  154,  145,  142,  142,  143,  149,  151,  152,

      144,  148,  153,  158,  154,  156,  159,  157,  152,  155,
      153,  155,  160,  156,  157,  161,  162,  163,  164,  165,
      158,  166,  168,  163,  164,  159,  162,  167,  178,  168,
      174,  174,  174,  174,  180,  160,  161,  178,  178,  165,
      165,  166,  180,  186,  186,  167,  177,  177,  177,  177,
      179,  179,  196,  196,  200,  179,  179,  179,  179,  179,
      179,  191,  191,  191,  191,  192,  192,  192,  192,  198,
      198,  199,  197,  197,  201,  209,  204,  200,  203,  205,
      202,  196,  201,  199,  206,  210,  212,  205,  214,  632,
      206,  630,  209,  191,  191,  191,  191,  191,  191,  197,

      202,  203,  204,  208,  211,  213,  212,  210,  214,  213,
      215,  208,  216,  211,  211,  219,  218,  220,  221,  216,
      218,  223,  215,  225,  224,  226,  227,  228,  223,  220,
      219,  229,  218,  225,  230,  221,  224,  234,  231,  228,
      232,  233,  235,  236,  234,  226,  231,  237,  241,  233,
      240,  230,  227,  229,  238,  236,  232,  242,  240,  238,
      237,  243,  235,  244,  245,  246,  250,  248,  243,  241,
      249,  244,  252,  253,  254,  245,  248,  242,  250,  256,
      257,  255,  278,  278,  629,  246,  253,  261,  252,  248,
      254,  255,  256,  249,  258,  257,  261,  261,  262,  262,

      279,  280,  258,  262,  262,  262,  262,  262,  262,  273,
      273,  273,  273,  281,  279,  282,  286,  287,  277,  283,
      277,  277,  280,  283,  288,  289,  290,  286,  281,  288,
      292,  294,  287,  289,  296,  290,  290,  293,  282,  296,
      300,  273,  273,  273,  273,  273,  273,  277,  297,  293,
      292,  299,  297,  294,  301,  302,  303,  304,  305,  299,
      300,  306,  307,  309,  313,  314,  311,  323,  306,  302,
      323,  314,  317,  316,  301,  312,  305,  303,  307,  304,
      311,  316,  628,  309,  310,  310,  313,  310,  310,  310,
      310,  310,  310,  310,  310,  312,  310,  318,  317,  310,

      310,  310,  319,  324,  321,  318,  319,  327,  326,  328,
      325,  333,  354,  328,  327,  324,  326,  354,  329,  317,
      321,  329,  331,  333,  310,  310,  310,  325,  356,  330,
      331,  627,  310,  330,  335,  335,  336,  335,  335,  335,
      335,  335,  335,  335,  335,  336,  336,  353,  356,  335,
      335,  335,  346,  346,  346,  346,  349,  349,  355,  359,
      358,  361,  355,  350,  350,  358,  360,  359,  363,  353,
      361,  361,  370,  363,  335,  335,  335,  362,  366,  365,
      621,  360,  620,  349,  346,  346,  346,  346,  346,  346,
      350,  365,  362,  366,  367,  373,  375,  376,  370,  378,

      375,  367,  380,  373,  379,  379,  376,  384,  385,  387,
      384,  388,  389,  390,  393,  378,  380,  392,  380,  394,
      393,  397,  399,  396,  391,  489,  398,  387,  385,  400,
      419,  392,  489,  388,  389,  390,  391,  396,  391,  403,
      394,  398,  391,  397,  399,  400,  417,  379,  403,  403,
      414,  414,  415,  415,  417,  418,  419,  420,  421,  422,
      423,  425,  424,  427,  422,  420,  426,  431,  423,  423,
      423,  427,  434,  428,  435,  418,  428,  414,  421,  424,
      426,  432,  431,  436,  425,  432,  438,  442,  440,  434,
      438,  443,  444,  445,  446,  443,  447,  449,  450,  435,

      440,  445,  465,  442,  444,  436,  450,  455,  467,  452,
      468,  446,  444,  452,  469,  455,  455,  455,  447,  466,
      466,  471,  474,  449,  473,  473,  475,  482,  467,  471,
      472,  465,  476,  479,  469,  478,  468,  480,  472,  472,
      472,  479,  474,  480,  476,  484,  485,  486,  475,  482,
      478,  487,  485,  488,  490,  492,  494,  493,  488,  496,
      487,  530,  484,  619,  486,  493,  514,  499,  518,  492,
      530,  490,  618,  496,  494,  499,  499,  499,  500,  500,
      509,  509,  510,  510,  510,  517,  514,  515,  515,  521,
      518,  519,  523,  517,  525,  519,  524,  521,  526,  527,

      528,  550,  525,  532,  523,  533,  617,  509,  528,  524,
      532,  537,  537,  533,  526,  551,  527,  542,  542,  544,
      544,  545,  545,  546,  546,  548,  548,  550,  554,  555,
      559,  560,  561,  616,  554,  561,  551,  555,  565,  565,
      568,  568,  612,  560,  559,  567,  544,  569,  567,  567,
      574,  569,  567,  570,  570,  571,  571,  576,  571,  571,
      572,  572,  567,  574,  577,  576,  584,  579,  580,  568,
      583,  583,  590,  590,  584,  592,  592,  595,  597,  613,
      577,  579,  622,  580,  598,  607,  597,  606,  598,  601,
      601,  608,  608,  609,  609,  610,  610,  615,  615,  590,

      613,  625,  595,  623,  623,  624,  624,  622,  626,  626,
      633,  633,  635,  635,  625,  638,  638,  605,  608,  645,
      645,  651,  651,  652,  652,  653,  653,  653,  654,  654,
      655,  655,  656,  656,  624,  657,  657,  626,  657,  657,
      604,  635,  659,  659,  638,  660,  660,  663,  663,  663,
      663,  663,  663,  663,  663,  663,  664,  664,  664,  664,
      664,  664,  664,  664,  664,  665,  665,  665,  665,  665,
      665,  665,  665,  665,  666,  666,  666,  666,  666,  666,
      666,  666,  666,  667,  667,  667,  667,  667,  667,  667,
      667,  667,  668,  668,  668,  668,  668,  668,  668,  668,

      668,  669,  669,  669,  669,  669,  669,  669,  669,  669,
      670,  670,  670,  670,  670,  670,  670,  670,  670,  671,
      671,  671,  671,  671,  671,  671,  671,  671,  672,  672,
      672,  672,  672,  672,  672,  672,  672,  673,  673,  673,
      673,  673,  673,  673,  673,  673,  674,  603,  674,  675,
      675,  602,  600,  675,  675,  675,  599,  675,  676,  676,
      676,  676,  676,  676,  676,  676,  676,  677,  596,  594,
      593,  677,  677,  677,  677,  677,  678,  678,  679,  591,
      679,  588,  679,  680,  680,  587,  680,  680,  680,  680,
      680,  680,  681,  681,  586,  681,  681,  681,  681,  681,

      681,  682,  682,  585,  682,  682,  682,  682,  682,  682,
      582,  581,  578,  575,  573,  564,  563,  562,  558,  557,
      556,  553,  552,  549,  547,  541,  538,  536,  535,  534,
      531,  529,  522,  520,  516,  513,  512,  511,  508,  507,
      506,  505,  503,  501,  498,  497,  495,  491,  481,  477,
      470,  464,  463,  462,  461,  459,  458,  457,  456,  454,
      453,  451,  448,  441,  439,  437,  433,  430,  429,  416,
      412,  411,  410,  409,  408,  407,  406,  405,  404,  402,
      401,  395,  386,  383,  382,  381,  377,  374,  372,  371,
      369,  368,  364,  357,  352,  351,  347,  345,  344,  343,

      342,  341,  340,  339,  338,  337,  334,  332,  322,  320,
      315,  308,  298,  295,  291,  285,  284,  276,  274,  272,
      271,  269,  268,  267,  266,  265,  264,  263,  260,  259,
      251,  247,  239,  222,  217,  207,  194,  193,  190,  189,
      188,  187,  184,  183,  182,  181,  176,  115,  111,  110,
       86,   40,   33,   25,   24,   23,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,

      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662,  662,  662,  662,  662,  662,  662,
      662,  662,  662,  662
    } ;

#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = yyg->yy_hold_char; /* undo effects of setting up yytext */ \
yy_cp = yyg->yy_full_match; /* restore poss. backed-over text */ \
yyg->yy_lp = yyg->yy_full_lp; /* restore orig. accepting pos. */ \
yyg->yy_state_ptr = yyg->yy_full_state; /* restore orig. state */ \
yy_current_state = *yyg->yy_state_ptr; /* restore curr. state */ \
++yyg->yy_lp; \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "scanner.l"
/*
 * Copyright (c) 1999-2008 NOVELL (All rights reserved)
 * Copyright (c) 2010, Canonical, Ltd.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU General Public
 * License published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
#line 28 "scanner.l"

#include "grammar.h"
#include <aalogparse.h>
#include "parser.h"

#include <assert.h>

#define YY_NO_INPUT

unsigned int string_buf_alloc = 0;
unsigned int string_buf_len = 0;
char *string_buf = NULL;

void string_buf_reset()
{
	/* rewind buffer to zero, possibly doing initial allocation too */
	string_buf_len = 0;
 	if (string_buf == NULL) {
		string_buf_alloc = 128;
		string_buf = malloc(string_buf_alloc);
		assert(string_buf != NULL);
	}
	/* always start with a valid but empty string */
	string_buf[0] = '\0';
}

void string_buf_append(unsigned int length, char *text)
{
	unsigned int current_length = string_buf_len;

	/* handle calling ..._append before ..._reset */
	if (string_buf == NULL) string_buf_reset();

	string_buf_len += length;
	/* expand allocation if this append would exceed the allocation */
	while (string_buf_len >= string_buf_alloc) {
		string_buf_alloc *= 2;
		string_buf = realloc(string_buf, string_buf_alloc);
		assert(string_buf != NULL);
	}
	/* copy and unconditionally terminate */
	memcpy(string_buf+current_length, text, length);
	string_buf[string_buf_len] = '\0';
}

#line 1345 "scanner.c"
/* New message types */
/* Key tokens */
/* network addrs */
/* syslog tokens */

#line 1351 "scanner.c"

#define INITIAL 0
#define single_quoted_string 1
#define quoted_string 2
#define sub_id 3
#define audit_id 4
#define hostname 5
#define dmesg_timestamp 6
#define safe_string 7
#define audit_types 8
#define ip_addr 9
#define other_audit 10
#define unknown_message 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    yy_state_type *yy_state_buf;
    yy_state_type *yy_state_ptr;
    char *yy_full_match;
    int yy_lp;

    /* These are only needed for trailing context rules,
     * but there's no conditional variable for that yet. */
    int yy_looking_for_trail_begin;
    int yy_full_lp;
    int *yy_full_state;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

YYSTYPE * yyget_lval ( yyscan_t yyscanner );

void yyset_lval ( YYSTYPE * yylval_param , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

    static void yy_push_state ( int _new_state , yyscan_t yyscanner);
    
    static void yy_pop_state ( yyscan_t yyscanner );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner);

#define YY_DECL int yylex \
               (YYSTYPE * yylval_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! yyg->yy_state_buf )
            yyg->yy_state_buf = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  , yyscanner);
            if ( ! yyg->yy_state_buf )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 199 "scanner.l"


#line 202 "scanner.l"
yy_flex_debug = 0;



#line 1663 "scanner.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;

		yyg->yy_state_ptr = yyg->yy_state_buf;
		*yyg->yy_state_ptr++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 663 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*yyg->yy_state_ptr++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1557 );

yy_find_action:
		yy_current_state = *--yyg->yy_state_ptr;
		yyg->yy_lp = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( yyg->yy_lp && yyg->yy_lp < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[yyg->yy_lp];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     yyg->yy_looking_for_trail_begin )
					{
					if ( yy_act == yyg->yy_looking_for_trail_begin )
						{
						yyg->yy_looking_for_trail_begin = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					yyg->yy_looking_for_trail_begin = yy_act & ~YY_TRAILING_MASK;
					yyg->yy_looking_for_trail_begin |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					yyg->yy_full_match = yy_cp;
					yyg->yy_full_state = yyg->yy_state_ptr;
					yyg->yy_full_lp = yyg->yy_lp;
					break;
					}
				++yyg->yy_lp;
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--yyg->yy_state_ptr;
			yyg->yy_lp = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 206 "scanner.l"
{ /* Skip whitespace */ }
	YY_BREAK

case 2:
YY_RULE_SETUP
#line 209 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_AUDIT_DIGITS);}
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 210 "scanner.l"
{ yy_pop_state(yyscanner); return(TOK_COLON); }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 211 "scanner.l"
{ return(TOK_COLON); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 212 "scanner.l"
{ return(TOK_PERIOD); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 213 "scanner.l"
{ return(TOK_OPEN_PAREN); }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 214 "scanner.l"
{ yy_pop_state(yyscanner); return(TOK_CLOSE_PAREN); }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 215 "scanner.l"
{ BEGIN(unknown_message); yyless(0); /* dump the rest */ }
	YY_BREAK


case 9:
YY_RULE_SETUP
#line 219 "scanner.l"
{ return(TOK_OPEN_PAREN); }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 220 "scanner.l"
{ BEGIN(INITIAL); return(TOK_CLOSE_PAREN); }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 221 "scanner.l"
{ }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 222 "scanner.l"
{ string_buf_reset(); BEGIN(quoted_string); }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 223 "scanner.l"
{
			yylval->t_str = strdup(yytext);
			BEGIN(INITIAL);
			return(TOK_ID);
		}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 228 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK

case 15:
YY_RULE_SETUP
#line 231 "scanner.l"
{ string_buf_reset(); BEGIN(quoted_string); }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 232 "scanner.l"
{ /* End of the quoted string */
				BEGIN(INITIAL);
				yylval->t_str = strdup(string_buf);
				return(TOK_QUOTED_STRING);
			}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 239 "scanner.l"
{ string_buf_append(1, &yytext[1]); }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 241 "scanner.l"
{ string_buf_append(yyleng, yytext); }
	YY_BREAK

case 19:
YY_RULE_SETUP
#line 244 "scanner.l"
{ string_buf_reset(); BEGIN(quoted_string); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 245 "scanner.l"
{ yylval->t_str = hex_to_string(yytext); BEGIN(INITIAL); return(TOK_HEXSTRING);}
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 246 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 247 "scanner.l"
{ /* eek, error! try another state */ BEGIN(INITIAL); yyless(0); }
	YY_BREAK


case 23:
YY_RULE_SETUP
#line 251 "scanner.l"
{ yylval->t_str = strdup(yytext); yy_pop_state(yyscanner); return(TOK_IP_ADDR); }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 252 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 253 "scanner.l"
{ /* eek, error! try another state */ BEGIN(INITIAL); yyless(0); }
	YY_BREAK


case 26:
YY_RULE_SETUP
#line 257 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 258 "scanner.l"
{ yylval->t_long = atol(yytext); BEGIN(INITIAL); return(TOK_DIGITS); }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 259 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_REJECT); }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 260 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AUDIT); }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 261 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_COMPLAIN); }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 262 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_HINT); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 263 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_STATUS); }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 264 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_ERROR); }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 265 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_REJECT); }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 266 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_AUDIT); }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 267 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_COMPLAIN); }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 268 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_HINT); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 269 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_STATUS); }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 270 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_AA_ERROR); }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 271 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_LSM_AVC); }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 272 "scanner.l"
{ BEGIN(INITIAL); return(TOK_TYPE_USER_AVC); }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 273 "scanner.l"
{ char *yptr = yytext;
			  while (*yptr && *yptr != '[')
			  	yptr++;
			  if (*yptr)
			  	yylval->t_long = atol(yptr + 1); /* skip '[' */
			  BEGIN(INITIAL);
			  return(TOK_TYPE_UNKNOWN);
			}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 281 "scanner.l"
{ yylval->t_str = strdup(yytext);
			      BEGIN(other_audit);
			      return(TOK_TYPE_OTHER);
			}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 285 "scanner.l"
{ BEGIN(unknown_message); yyless(0); /* dump the rest */ }
	YY_BREAK

case 45:
YY_RULE_SETUP
#line 288 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 289 "scanner.l"
{ yylval->t_long = atol(yytext); return(TOK_DIGITS); }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 290 "scanner.l"
{ return(TOK_COLON); }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 291 "scanner.l"
{ return(TOK_MINUS); }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 292 "scanner.l"
{
			BEGIN(sub_id);
			return(TOK_OPEN_PAREN);
			}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 296 "scanner.l"
{ return(TOK_CLOSE_PAREN); }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 297 "scanner.l"
{ return(TOK_PERIOD); }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 298 "scanner.l"
{ return(TOK_QUESTION_MARK); }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 299 "scanner.l"
{ return(TOK_SINGLE_QUOTE); }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 301 "scanner.l"
{ BEGIN(audit_types); return(TOK_KEY_APPARMOR); }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 302 "scanner.l"
{ BEGIN(audit_types); return(TOK_KEY_TYPE); }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 303 "scanner.l"
{ return(TOK_KEY_MSG); }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 304 "scanner.l"
{ return(TOK_KEY_OPERATION); }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 305 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_NAME); }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 306 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_NAME2); }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 307 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_NAMESPACE); }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 308 "scanner.l"
{ return(TOK_KEY_MASK); }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 309 "scanner.l"
{ return(TOK_KEY_DENIED_MASK); }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 310 "scanner.l"
{ return(TOK_KEY_REQUESTED_MASK); }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 311 "scanner.l"
{ BEGIN(sub_id); return(TOK_KEY_ATTRIBUTE); }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 312 "scanner.l"
{ return(TOK_KEY_TASK); }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 313 "scanner.l"
{ return(TOK_KEY_PARENT); }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 314 "scanner.l"
{ return(TOK_KEY_MAGIC_TOKEN); }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 315 "scanner.l"
{ return(TOK_KEY_INFO); }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 316 "scanner.l"
{ return(TOK_KEY_PEER_INFO); }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 317 "scanner.l"
{ return(TOK_KEY_PID); }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 318 "scanner.l"
{ return(TOK_KEY_PEER_PID); }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 319 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PROFILE); }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 320 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PEER_PROFILE); }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 321 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_LABEL); }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 322 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PEER_LABEL); }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 323 "scanner.l"
{ return(TOK_KEY_FAMILY); }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 324 "scanner.l"
{ return(TOK_KEY_SOCK_TYPE); }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 325 "scanner.l"
{ return(TOK_KEY_PROTOCOL); }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 326 "scanner.l"
{ return(TOK_KEY_ERROR); }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 327 "scanner.l"
{ return(TOK_KEY_FSUID); }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 328 "scanner.l"
{ return(TOK_KEY_OUID); }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 329 "scanner.l"
{ return(TOK_KEY_UID); }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 330 "scanner.l"
{ return(TOK_KEY_AUID); }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 331 "scanner.l"
{ return(TOK_KEY_SAUID); }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 332 "scanner.l"
{ return(TOK_KEY_SES); }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 333 "scanner.l"
{ return(TOK_KEY_HOSTNAME); }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 334 "scanner.l"
{ return(TOK_KEY_ADDR); }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 335 "scanner.l"
{ return(TOK_KEY_TERMINAL); }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 336 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_EXE); }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 337 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_COMM); }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 338 "scanner.l"
{ return(TOK_KEY_CAPABILITY); }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 339 "scanner.l"
{ return(TOK_KEY_CAPNAME); }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 340 "scanner.l"
{ return(TOK_KEY_OFFSET); }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 341 "scanner.l"
{ return(TOK_KEY_TARGET); }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 342 "scanner.l"
{ yy_push_state(ip_addr, yyscanner); return(TOK_KEY_LADDR); }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 343 "scanner.l"
{ yy_push_state(ip_addr, yyscanner); return(TOK_KEY_FADDR); }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 344 "scanner.l"
{ return(TOK_KEY_LPORT); }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 345 "scanner.l"
{ return(TOK_KEY_FPORT); }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 346 "scanner.l"
{ return(TOK_KEY_BUS); }
	YY_BREAK
case 100:
YY_RULE_SETUP
#line 347 "scanner.l"
{ return(TOK_KEY_PATH); }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 348 "scanner.l"
{ return(TOK_KEY_INTERFACE); }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 349 "scanner.l"
{ return(TOK_KEY_MEMBER); }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 350 "scanner.l"
{ BEGIN(sub_id); return(TOK_KEY_SIGNAL); }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 351 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_PEER); }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 352 "scanner.l"
{ return(TOK_KEY_FSTYPE); }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 353 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_FLAGS); }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 354 "scanner.l"
{ BEGIN(safe_string); return(TOK_KEY_SRCNAME); }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 356 "scanner.l"
{ BEGIN(dmesg_timestamp); return(TOK_SOCKLOGD_KERNEL); }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 357 "scanner.l"
{ BEGIN(dmesg_timestamp); return(TOK_SYSLOG_KERNEL); }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 358 "scanner.l"
{ return(TOK_SYSLOG_USER); }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 359 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_DATE_MONTH); }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 360 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_DATE); }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 361 "scanner.l"
{ yylval->t_str = strndup(yytext, strlen(yytext)-1); return(TOK_DATE); }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 362 "scanner.l"
{ yylval->t_str = strdup(yytext); BEGIN(hostname); return(TOK_TIME); }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 364 "scanner.l"
{ yy_push_state(audit_id, yyscanner); return(TOK_AUDIT); }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 365 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_DMESG_STAMP); }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 367 "scanner.l"
{ /* ignore any non-matched input */ BEGIN(unknown_message); yyless(0); }
	YY_BREAK

case 118:
/* rule 118 can match eol */
YY_RULE_SETUP
#line 370 "scanner.l"
{ /* eat whitespace */ }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 371 "scanner.l"
{ BEGIN(dmesg_timestamp); return(TOK_SOCKLOGD_KERNEL); }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 372 "scanner.l"
{ yylval->t_str = strdup(yytext); BEGIN(INITIAL); return(TOK_ID); }
	YY_BREAK


case 121:
/* rule 121 can match eol */
YY_RULE_SETUP
#line 376 "scanner.l"
{ /* eat whitespace */ }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 377 "scanner.l"
{ yylval->t_str = strdup(yytext); BEGIN(INITIAL); return(TOK_DMESG_STAMP); }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 378 "scanner.l"
{ /* no timestamp in this message */ BEGIN(INITIAL); yyless(0); }
	YY_BREAK


case 124:
/* rule 124 can match eol */
YY_RULE_SETUP
#line 382 "scanner.l"
{ /* eat whitespace */ }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 383 "scanner.l"
{ yy_push_state(audit_id, yyscanner); return(TOK_AUDIT); }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 384 "scanner.l"
{ return(TOK_KEY_MSG); }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 385 "scanner.l"
{ return(TOK_EQUALS); }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 386 "scanner.l"
{ return(TOK_COLON); }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 387 "scanner.l"
{ BEGIN(unknown_message); yyless(0); /* dump the rest */ }
	YY_BREAK


case 130:
YY_RULE_SETUP
#line 391 "scanner.l"
{ yylval->t_str = strdup(yytext); return(TOK_MSG_REST); }
	YY_BREAK
case 131:
/* rule 131 can match eol */
YY_RULE_SETUP
#line 392 "scanner.l"
{ /* not sure why needed here and not elsewhere */ }
	YY_BREAK

case 132:
YY_RULE_SETUP
#line 396 "scanner.l"
ECHO;
	YY_BREAK
#line 2450 "scanner.c"
			case YY_STATE_EOF(INITIAL):
			case YY_STATE_EOF(single_quoted_string):
			case YY_STATE_EOF(quoted_string):
			case YY_STATE_EOF(sub_id):
			case YY_STATE_EOF(audit_id):
			case YY_STATE_EOF(hostname):
			case YY_STATE_EOF(dmesg_timestamp):
			case YY_STATE_EOF(safe_string):
			case YY_STATE_EOF(audit_types):
			case YY_STATE_EOF(ip_addr):
			case YY_STATE_EOF(other_audit):
			case YY_STATE_EOF(unknown_message):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	yyg->yy_state_ptr = yyg->yy_state_buf;
	*yyg->yy_state_ptr++ = yy_current_state;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 663 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*yyg->yy_state_ptr++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 663 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 662);
	if ( ! yy_is_jam )
		*yyg->yy_state_ptr++ = yy_current_state;

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  _new_state , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( yyg->yy_start_stack_ptr >= yyg->yy_start_stack_depth )
		{
		yy_size_t new_size;

		yyg->yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = (yy_size_t) yyg->yy_start_stack_depth * sizeof( int );

		if ( ! yyg->yy_start_stack )
			yyg->yy_start_stack = (int *) yyalloc( new_size , yyscanner );

		else
			yyg->yy_start_stack = (int *) yyrealloc(
					(void *) yyg->yy_start_stack, new_size , yyscanner );

		if ( ! yyg->yy_start_stack )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	yyg->yy_start_stack[yyg->yy_start_stack_ptr++] = YY_START;

	BEGIN(_new_state);
}

    static void yy_pop_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( --yyg->yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yyg->yy_start_stack[yyg->yy_start_stack_ptr]);
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

    yyg->yy_state_buf = 0;
    yyg->yy_state_ptr = 0;
    yyg->yy_full_match = 0;
    yyg->yy_lp = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    yyfree ( yyg->yy_state_buf , yyscanner);
    yyg->yy_state_buf  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 396 "scanner.l"


